.. _pecan_secure:

:mod:`pecan.secure` -- Pecan Secure Controllers
===============================================

The :mod:`pecan.secure` module includes a basic framework for building
security into your applications.

.. automodule:: pecan.secure
  :members:
  :show-inheritance: